@@ -4,12 +4,22 @@ from web3 import Web3, HTTPProvider
 from typing import Optional
 
 from .errors import NoSignerException
-from .modules import CurrencyModule, NftModule, PackModule, CollectionModule
+from .modules.nft import NftModule
+from .modules.pack import PackModule
+from .modules.collection import CollectionModule
+from .modules.currency import CurrencyModule
+from .modules.market import MarketModule
 from .options import SdkOptions
 from .storage import IpfsStorage
 
 from zero_ex.contract_wrappers import TxParams
 
+def set_default_account(func):
+	def wrapper(self, *args, **kwargs):
+		self.client.eth.defaultAccount = args[0] if self.signer_address == "" else self.signer_address
+		return func(self, *args, **kwargs)
+	return wrapper
+
 
 class NftlabsSdk(object):
 	client: Web3
@@ -25,18 +35,18 @@ class NftlabsSdk(object):
 	__nft_module: Optional[NftModule]
 	__pack_module: Optional[PackModule]
 	__collection_module: Optional[CollectionModule]
+	__market_module: Optional[MarketModule]
 
 	"""
 	Create instance of the NftlabsSdk
 	"""
 	def __init__(self, options: SdkOptions, url: str):
-		print("Created Nftlabs SDK!")
-
 		self.__currency_module = None
 		self.__nft_module = None
 		self.__pack_module = None
 		self.__collection_module = None
 		self.__current_account = None
+		self.__market_module = None
 
 		self.options = options
 		if self.options.private_key != "":
@@ -64,6 +74,7 @@ class NftlabsSdk(object):
 	"""
 	Returns an instance of the currency module
 	"""
+	@set_default_account
 	def get_currency_module(self, address: str) -> CurrencyModule:
 		if self.__currency_module is not None:
 			return self.__currency_module
@@ -76,6 +87,7 @@ class NftlabsSdk(object):
 	"""
 	Returns an instance of the nft module
 	"""
+	@set_default_account
 	def get_nft_module(self, address: str) -> NftModule:
 		if self.__nft_module is not None:
 			return self.__nft_module
@@ -88,6 +100,7 @@ class NftlabsSdk(object):
 	"""
 	Returns an instance of the pack module
 	"""
+	@set_default_account
 	def get_pack_module(self, address: str) -> PackModule:
 		if self.__pack_module is not None:
 			return self.__pack_module
@@ -97,9 +110,23 @@ class NftlabsSdk(object):
 		self.__pack_module = module
 		return self.__pack_module
 
+	"""
+	Returns an instance of the market module
+	"""
+	@set_default_account
+	def get_market_module(self, address: str) -> MarketModule:
+		if self.__market_module is not None:
+			return self.__market_module
+		
+		module = MarketModule(address, self.__get_client())
+		self.__init_module(module)
+		self.__market_module = module
+		return self.__market_module
+
 	"""
 	Returns an instance of the collection module
 	"""
+	@set_default_account
 	def get_collection_module(self, address: str) -> CollectionModule:
 		if self.__collection_module is not None:
 			return self.__collection_module
